@@ -1,16 +1,16 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -18,8 +18,6 @@
  *
  */
 
-
-
 #include "BTextCtrl.h"
 #include <wx/config.h>
 
@@ -29,7 +27,7 @@ BTextCtrl::BTextCtrl(wxWindow *parent,
                     const wxPoint& pos,
                     const wxSize& size,
                     long style)
- : wxTextCtrl(parent, id, value, pos, size, style|wxTE_RICH)
+ : wxTextCtrl(parent, id, value, pos, size, style)
 {
   bool fixedFont = true;
   m_matchParens = true;
@@ -37,7 +35,9 @@ BTextCtrl::BTextCtrl(wxWindow *parent,
   config->Read(wxT("matchParens"), &m_matchParens);
   config->Read(wxT("fixedFontTC"), &fixedFont);
   if (fixedFont) {
-#if defined(__WXGTK12__) && !defined(__WXGTK20__)
+#if defined (__WXGTK12__) && !defined (__WXGTK20__)
+    SetFont(wxFont(12, wxMODERN, wxNORMAL, wxNORMAL, 0, wxEmptyString));
+#elif defined (__WXMAC__)
     SetFont(wxFont(12, wxMODERN, wxNORMAL, wxNORMAL, 0, wxEmptyString));
 #else
     SetFont(wxFont(10, wxMODERN, wxNORMAL, wxNORMAL, 0, wxEmptyString));
@@ -52,10 +52,8 @@ BTextCtrl::~BTextCtrl()
 
 void BTextCtrl::OnChar(wxKeyEvent& event)
 {
-  if (!m_matchParens || MatchParenthesis(event.GetKeyCode())) {
+  if (!m_matchParens || MatchParenthesis(event.GetKeyCode()))
     event.Skip();
-    return;
-  }
 }
 
 bool BTextCtrl::MatchParenthesis(int code)
@@ -85,7 +83,7 @@ bool BTextCtrl::MatchParenthesis(int code)
   default:
     break;
   }
-  
+
   return skip;
 }
 
@@ -93,7 +91,7 @@ void BTextCtrl::CloseParenthesis(wxString open, wxString close)
 {
   long from, to;
   GetSelection(&from, &to);
-  
+
   if (from==to) {
     WriteText(open + close);
     SetInsertionPoint(GetInsertionPoint()-1);
