@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,19 +38,28 @@ enum {
   checkbox_header,
   button_symbol,
   checkbox_symbol,
-  font_family
+  font_family,
+  panel_size,
+  language_id
 };
 
 class ExamplePanel : public wxPanel {
 public:
-  ExamplePanel(wxWindow *parent, int id, wxPoint pos, wxSize size) : wxPanel(parent, id, pos, size) { };
-  void SetStyle(wxString fg_color, bool italic, bool bold, bool underlined, wxString font, int size) {
+  ExamplePanel(wxWindow *parent, int id, wxPoint pos, wxSize size) : wxPanel(parent, id, pos, size) {
+#if defined (__WXGTK12__) && !defined (__WXGTK20__)
+    m_size = 12;
+#elif defined (__WXMAC__)
+    m_size = 12;
+#else
+    m_size = 10;
+#endif
+  };
+  void SetStyle(wxString fg_color, bool italic, bool bold, bool underlined, wxString font) {
     m_fgColor = fg_color;
     m_italic = italic;
     m_bold = bold;
     m_underlined = underlined;
     m_font = font;
-    m_size = size;
   }
 private:
   void OnPaint(wxPaintEvent& event);
@@ -86,6 +95,8 @@ protected:
   wxTextCtrl* m_additionalParameters;
   wxStaticText* label_4;
   wxComboBox* m_language;
+  wxStaticText* label_9;
+  wxComboBox* m_panelSize;
   wxCheckBox* m_saveSize;
   wxCheckBox* m_matchParens;
   wxCheckBox* m_showLong;
@@ -114,12 +125,14 @@ protected:
   // end wxGlade
   style m_styleNormalText, m_styleHiddenText, m_styleMainPrompt,
         m_styleOtherPrompt, m_styleLabel, m_styleSpecial, m_styleInput,
-        m_styleBackground;
+        m_styleBackground, m_styleNumber, m_styleString, m_styleGreek,
+        m_styleVariable, m_styleHighlight;
   void OnOk(wxCommandEvent& event);
   void OnMpBrowse(wxCommandEvent& event);
   void OnSymbolBrowse(wxCommandEvent& event);
   void OnChangeStyle(wxCommandEvent& event);
   void OnChangeColor(wxCommandEvent& event);
+  void OnChangeWarning(wxCommandEvent& event);
   void OnCheckbox(wxCommandEvent& event);
   void OnCheckSymbol(wxCommandEvent& event);
   void ReadStyles();
