@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,24 @@
 
 #include "MathCell.h"
 
+enum {
+  popid_copy,
+  popid_copy_text,
+  popid_copy_image,
+  popid_delete,
+  popid_simplify,
+  popid_expand,
+  popid_factor,
+  popid_solve,
+  popid_solve_num,
+  popid_integrate,
+  popid_diff,
+  popid_subst,
+  popid_plot2d,
+  popid_plot3d,
+  popid_float
+};
+
 class MathCtrl:public wxScrolledWindow
 {
   public:
@@ -65,6 +83,7 @@ class MathCtrl:public wxScrolledWindow
     void OnMouseEnter(wxMouseEvent& event);
     void OnPaint(wxPaintEvent& event);
     void OnSize(wxSizeEvent& event);
+    void OnMouseRightUp(wxMouseEvent& event);
     void OnMouseLeftUp(wxMouseEvent& event);
     void OnMouseLeftDown(wxMouseEvent& event);
     void OnMouseMotion(wxMouseEvent& event);
@@ -72,6 +91,7 @@ class MathCtrl:public wxScrolledWindow
     void SelectPoint(wxPoint& point);
     void SelectRect(wxPoint one, wxPoint two);
     void AdjustSize(bool scroll = false);
+    void OnEraseBackground(wxEraseEvent& event) { };
     wxPoint m_down;
     wxPoint m_up;
     wxPoint m_mousePoint;
