@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ MathCell* SqrtCell::Copy(bool all)
 {
   SqrtCell* tmp = new SqrtCell;
   tmp->SetInner(m_innerCell->Copy(true));
-  tmp->m_style = m_style;
+  tmp->m_type = m_type;
   if (all && m_next!=NULL)
     tmp->AppendCell(m_next->Copy(all));
   return tmp;
@@ -64,7 +64,7 @@ void SqrtCell::SetInner(MathCell *inner)
   if (m_innerCell != NULL)
     delete m_innerCell;
   m_innerCell = inner;
-  
+
   m_last = inner;
   while (m_last->m_next != NULL)
     m_last = m_last->m_next;
@@ -97,11 +97,11 @@ void SqrtCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
   if (DrawThisCell(parser, point)) {
     wxDC& dc = parser.GetDC();
     double scale = parser.GetScale();
-    
+
     wxPoint in(point);
     in.x += SCALE_PX(10, scale) + SCALE_PX(1, scale) + 1;
     m_innerCell->Draw(parser, in, fontsize, true);
-  
+
     SetPen(parser);
     dc.DrawLine(point.x,
                 point.y,
@@ -144,10 +144,10 @@ void SqrtCell::SelectInner(wxRect& rect, MathCell **first, MathCell **last)
 {
   *first = NULL;
   *last = NULL;
-  
+
   if (m_innerCell->ContainsRect(rect))
     m_innerCell->SelectRect(rect, first, last);
-  
+
   if (*first == NULL || *last == NULL) {
     *first = this;
     *last = this;
