@@ -1,16 +1,16 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -27,8 +27,8 @@
 
 class TextInput: public wxDialog {
  public:
-  TextInput(wxWindow* parent, int id, const wxString& title, bool setfont=true,
-            const wxPoint& pos=wxDefaultPosition,
+  TextInput(wxWindow* parent, int id=-1, const wxString& title=wxT(""),
+            bool setfont=true, const wxPoint& pos=wxDefaultPosition,
             const wxSize& size=wxDefaultSize,
             long style=wxDEFAULT_DIALOG_STYLE);
   wxString GetValue();
