@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
  *
  */
 
+
 #include "wxMaxima.h"
-#include "Version.h"
 #include "Config.h"
 #include "TextInput.h"
 #include "SubstituteWiz.h"
@@ -38,12 +38,12 @@
 #include "DragNDrop.h"
 #include "SystemWiz.h"
 #include "MathPrintout.h"
+#include "MyTipProvider.h"
 
 #include <wx/filedlg.h>
 #include <wx/utils.h>
 #include <wx/msgdlg.h>
 #include <wx/textfile.h>
-#include <wx/tipdlg.h>
 #include <wx/html/helpctrl.h>
 #include <wx/tokenzr.h>
 #include <wx/mimetype.h>
@@ -54,6 +54,10 @@ enum {
   maxima_process_id
 };
 
+#if defined (__WXMAC__)
+#define MACPREFIX "wxMaxima.app/Contents/Resources/"
+#endif
+
 wxMaxima::wxMaxima(wxWindow *parent, int id, const wxString title,
                    const wxPoint pos, const wxSize size) :
   wxMaximaFrame(parent,id,title,pos,size)
@@ -74,17 +78,19 @@ wxMaxima::wxMaxima(wxWindow *parent, int id, const wxString title,
   wxConfig::Get()->Read(wxT("lastPath"), &m_lastPath);
   m_lastPrompt = wxEmptyString;
 
-#if wxUSE_DRAG_AND_DROP
-  m_console->SetDropTarget(new FileDrop(this, m_inputLine, DND_LOAD));
-  m_inputLine->SetDropTarget(new FileDrop(this, m_inputLine, DND_WRITE));
+#if wxUSE_DRAG_AND_DROP && WXM_DND
+  m_console->SetDropTarget(new FileDrop(this));
 #endif
 
+#if WXM_PRINT
   CheckForPrintingSupport();
-
   m_printData = new wxPrintData;
   m_printData->SetQuality(wxPRINT_QUALITY_HIGH);
+#endif
+
   m_inputLine->SetFocus();
   m_closing = false;
+  m_openFile = wxEmptyString;
 }
 
 
@@ -92,13 +98,19 @@ wxMaxima::~wxMaxima()
 {
   if (m_client != NULL)
     m_client->Destroy();
+#if WXM_PRINT
   delete m_printData;
+#endif
 }
 
+#if WXM_PRINT
+
 void wxMaxima::CheckForPrintingSupport()
 {
 #if defined __WXMSW__
   m_supportPrinting = true;
+#elif defined __WXMAC__
+  m_supportPrinting = true;
 #elif defined wxUSE_LIBGNOMEPRINT
  #if wxUSE_LIBGNOMEPRINT
   wxLogNull log;
@@ -118,6 +130,8 @@ void wxMaxima::CheckForPrintingSupport()
 #endif
 }
 
+#endif
+
 void wxMaxima::InitSession()
 {
   while (!StartServer()) {
@@ -145,8 +159,8 @@ void wxMaxima::FirstOutput(wxString s)
   m_console->ClearWindow();
 
   if (showHeader)
-    ConsoleAppend(s.SubString(0, start-1), TEXTT);
-  ConsoleAppend(m_firstPrompt, PROMPTT);
+    ConsoleAppend(s.SubString(0, start-1), MC_TYPE_TEXT);
+  ConsoleAppend(m_firstPrompt, MC_TYPE_PROMPT);
 }
 
 ///////////////////////////
@@ -167,9 +181,9 @@ void wxMaxima::ConsoleAppend(wxString s, int type)
   if (!t.Length())
     return;
 
-  if (type != ERRORT)
+  if (type != MC_TYPE_ERROR)
     SetStatusText(_("Parsing output"), 1);
-  if (type == TEXTT) {
+  if (type == MC_TYPE_TEXT) {
     while (s.Length()>0) {
       int start = s.Find(wxT("<mth"));
       if (start == -1) {
@@ -177,7 +191,7 @@ void wxMaxima::ConsoleAppend(wxString s, int type)
         t.Trim();
         t.Trim(false);
         if (t.Length())
-          DoRawConsoleAppend(s, TEXTT);
+          DoRawConsoleAppend(s, MC_TYPE_TEXT);
         s = wxEmptyString;
       }
       else {
@@ -192,7 +206,7 @@ void wxMaxima::ConsoleAppend(wxString s, int type)
           end += 5;
         wxString rest = s.SubString(start, end);
         if (pre1.Length()) {
-          DoRawConsoleAppend(pre, TEXTT);
+          DoRawConsoleAppend(pre, MC_TYPE_TEXT);
           DoConsoleAppend(wxT("<span>") + rest +
                           wxT("</span>"), type, false);
         }
@@ -204,7 +218,7 @@ void wxMaxima::ConsoleAppend(wxString s, int type)
       }
     }
   }
-  else if (type == INPUTT) {
+  else if (type == MC_TYPE_INPUT) {
     // Break long lines
     unsigned int i=0;
     int j=0;
@@ -223,23 +237,25 @@ void wxMaxima::ConsoleAppend(wxString s, int type)
     // Append the input
     DoRawConsoleAppend(s, type, false);
   }
-  else if (type == PROMPTT) {
+  else if (type == MC_TYPE_PROMPT) {
     SetStatusText(_("Ready for user input"), 1);
     m_lastPrompt = s;
     if (s.StartsWith(wxT("(%i"))) {
       m_inPrompt = true;
-      type = MPROMPTT;
+      type = MC_TYPE_MAIN_PROMPT;
     }
-    else if (s.Right(8) == wxT("MAXIMA> ")) {
+    else if (s.StartsWith(wxT("MAXIMA> "))) {
       m_inPrompt = true;
-      type = MPROMPTT;
+      type = MC_TYPE_MAIN_PROMPT;
       s = s.Right(8);
     }
+    else
+      s = s + wxT(" ");
     DoConsoleAppend(wxT("<span>") + s + wxT("</span>"),
                     type, true);
   }
-  else if (type == ERRORT) {
-    DoRawConsoleAppend(s, ERRORT);
+  else if (type == MC_TYPE_ERROR) {
+    DoRawConsoleAppend(s, MC_TYPE_ERROR);
   }
   else {
     DoConsoleAppend(wxT("<span>") + s + wxT("</span>"),
@@ -253,16 +269,8 @@ void wxMaxima::DoConsoleAppend(wxString s, int type, bool newLine,
   MathCell* cell;
 
   s.Replace(wxT("\n"), wxT(""), true);
-  if (type == PROMPTT)
-    cell = m_MParser.ParseLine(s, TC_PROMPT);
-  else if (type == MPROMPTT)
-    cell = m_MParser.ParseLine(s, TC_MAIN_PROMPT);
-  else if (type == INPUTT)
-    cell = m_MParser.ParseLine(s, TC_INPUT);
-  else if (type == ERRORT)
-    cell = m_MParser.ParseLine(s, TC_ERROR);
-  else
-    cell = m_MParser.ParseLine(s);
+
+  cell = m_MParser.ParseLine(s, type);
 
   if (cell == NULL) {
     wxMessageBox(_("There was an error in generated XML!\n\n"
@@ -280,21 +288,13 @@ void wxMaxima::DoRawConsoleAppend(wxString s, int type, bool newLine)
   wxStringTokenizer tokens(s, wxT("\n"));
   int count = 0;
   while(tokens.HasMoreTokens()) {
-    TextCell* cell = new TextCell(tokens.GetNextToken());
-    if (type == PROMPTT)
-      cell->SetStyle(TC_PROMPT);
-    else if (type == MPROMPTT)
-      cell->SetStyle(TC_MAIN_PROMPT);
-    else if (type == INPUTT)
-      cell->SetStyle(TC_INPUT);
-    else if (type == ERRORT)
-      cell->SetStyle(TC_ERROR);
-    else
-      cell->SetStyle(TC_VARIABLE);
-    
+    TextCell* cell = new TextCell(RemoveTabs(tokens.GetNextToken()));
+
+    cell->SetType(type);
+
     if (tokens.HasMoreTokens())
       cell->SetSkip(false);
-    
+
     if (count == 0)
       m_console->AddLine(cell, newLine);
     else
@@ -303,10 +303,32 @@ void wxMaxima::DoRawConsoleAppend(wxString s, int type, bool newLine)
   }
 }
 
+wxString wxMaxima::RemoveTabs(wxString s)
+{
+  int pos = 0;
+  char c;
+  wxString t = wxEmptyString;
+
+  for (int i=0; i<s.Length(); i++) {
+    c = s.GetChar(i);
+    if (c == '\t') {
+      do {
+        t += ' ';
+        pos++;
+      } while (pos%8!=0);
+    }
+    else {
+      t += c;
+      pos++;
+    }
+  }
+  return t;
+}
+
 void wxMaxima::SendMaxima(wxString s, bool clear, bool out, bool silent)
 {
   if (!m_isConnected) {
-    ConsoleAppend(wxT("\nNot connected to maxima!\n"), ERRORT);
+    ConsoleAppend(wxT("\nNot connected to maxima!\n"), MC_TYPE_ERROR);
     return;
   }
   if (s.StartsWith(wxT("<ml>"))) {
@@ -316,7 +338,7 @@ void wxMaxima::SendMaxima(wxString s, bool clear, bool out, bool silent)
   if (clear)
     m_inputLine->SetValue(wxEmptyString);
   if (out)
-    ConsoleAppend(s, INPUTT);
+    ConsoleAppend(s, MC_TYPE_INPUT);
   if (silent) {
     m_inputLine->AddToHistory(s);
     SetStatusText(_("Maxima is calculating"), 1);
@@ -378,7 +400,7 @@ void wxMaxima::ClientEvent(wxSocketEvent& event)
       ReadMath();
 
       ReadPrompt();
-      
+
       ReadLispError();
     }
     break;
@@ -386,7 +408,7 @@ void wxMaxima::ClientEvent(wxSocketEvent& event)
     if (!m_closing)
       ConsoleAppend(wxT("\nCLIENT: Lost socket connection ...\n"
                         "Restart maxima with 'Maxima->Restart maxima'.\n"),
-                    ERRORT);
+                    MC_TYPE_ERROR);
     m_pid = -1;
     GetMenuBar()->Enable(menu_interrupt_id, false);
     m_client->Destroy();
@@ -405,7 +427,7 @@ void wxMaxima::ReadFirstPrompt()
   if (start==-1)
     start = 0;
   FirstOutput(wxT("wxMaxima ")
-              wxT(WXMAXIMA_VERSION)
+              wxT(VERSION)
               wxT(" http://wxmaxima.sourceforge.net\n") +
               m_currentOutput.SubString(start, m_currentOutput.Length()-1));
 #endif // __WXMSW__
@@ -418,6 +440,10 @@ void wxMaxima::ReadFirstPrompt()
   m_first = false;
   m_inLispMode = false;
   SetStatusText(_("Ready for user input"), 1);
+  if (m_openFile.Length()) {
+    OpenFile(m_openFile);
+    m_openFile = wxEmptyString;
+  }
   m_currentOutput = wxEmptyString;
 }
 
@@ -427,7 +453,7 @@ void wxMaxima::ReadMath()
   while (end > -1) {
     m_readingPrompt = true;
     wxString o = m_currentOutput.Left(end);
-    ConsoleAppend(o, TEXTT);
+    ConsoleAppend(o, MC_TYPE_TEXT);
     m_currentOutput = m_currentOutput.SubString(end+m_promptPrefix.Length(),
                                                 m_currentOutput.Length());
     end = m_currentOutput.Find(m_promptPrefix);
@@ -437,7 +463,7 @@ void wxMaxima::ReadMath()
   end = m_currentOutput.Find(mth);
   while (end > -1) {
     wxString o = m_currentOutput.Left(end);
-    ConsoleAppend(o + mth, TEXTT);
+    ConsoleAppend(o + mth, MC_TYPE_TEXT);
     m_currentOutput = m_currentOutput.SubString(end+mth.Length(),
                                                 m_currentOutput.Length());
     end = m_currentOutput.Find(mth);
@@ -451,7 +477,10 @@ void wxMaxima::ReadPrompt()
     m_readingPrompt = false;
     wxString o = m_currentOutput.Left(end);
     if (o != wxT("\n") && o.Length()) {
-      ConsoleAppend(o, PROMPTT);
+      if (o.StartsWith(wxT("(%i")) || o.StartsWith(wxT("MAXIMA> ")) || o.Find(wxT("<mth>"))>=0)
+        ConsoleAppend(o, MC_TYPE_PROMPT);
+      else
+        DoRawConsoleAppend(o, MC_TYPE_PROMPT);
       if (o.StartsWith(wxT("\nMAXIMA>")))
         m_inLispMode = true;
       else
@@ -475,8 +504,8 @@ void wxMaxima::ReadLispError()
     m_readingPrompt = false;
     m_inLispMode = true;
     wxString o = m_currentOutput.Left(end);
-    ConsoleAppend(o, TEXTT);
-    ConsoleAppend(lispError, PROMPTT);
+    ConsoleAppend(o, MC_TYPE_TEXT);
+    ConsoleAppend(lispError, MC_TYPE_PROMPT);
     SetStatusText(_("Ready for user input"), 1);
     m_currentOutput = wxEmptyString;
   }
@@ -502,7 +531,7 @@ void wxMaxima::ServerEvent(wxSocketEvent& event)
     if (!m_closing)
       ConsoleAppend(wxT("\nSERVER: Lost socket connection ...\n"
                         "Restart maxima with 'Maxima->Restart maxima'.\n"),
-                    ERRORT);
+                    MC_TYPE_ERROR);
     m_pid = -1;
     GetMenuBar()->Enable(menu_interrupt_id, false);
     m_isConnected = false;
@@ -522,7 +551,7 @@ void wxMaxima::ReadProcessOutput()
   if (st==-1)
     st = 0;
   FirstOutput(wxT("wxMaxima ")
-              wxT(WXMAXIMA_VERSION)
+              wxT(VERSION)
               wxT(" http://wxmaxima.sourceforge.net\n") +
               o.SubString(st, o.Length()-1));
   m_inPrompt = true;
@@ -545,6 +574,11 @@ void wxMaxima::SetupVariables()
   cwd.Replace(wxT("\\"), wxT("/"));
   SendMaxima(wxT(":lisp-quiet ($load \"") + cwd + wxT("/data/wxmathml\")"),
              false, false, false);
+#elif defined (__WXMAC__)
+  wxString cwd = wxGetCwd();
+  cwd = cwd + wxT("/") + wxT(MACPREFIX);
+  SendMaxima(wxT(":lisp-quiet ($load \"") + cwd + wxT("wxmathml\")"),
+	     false, false, false);
 #else
   wxString prefix = wxT(PREFIX);
   SendMaxima(wxT(":lisp-quiet ($load \"") + prefix +
@@ -653,7 +687,7 @@ bool wxMaxima::StartMaxima()
       command = maximaPrefix + wxT("\\lib\\maxima");
       if (!wxDirExists(command))
         return false;
-      
+
       wxArrayString files;
       wxDir::GetAllFiles(command, &files, wxT("maxima.exe"));
       if (files.Count() == 0)
@@ -716,14 +750,19 @@ void wxMaxima::ShowTip(bool force)
   config->Read(wxT("tipNum"), &tipNum);
   if (!ShowTips && !force)
     return;
+  wxString tips = wxT("tips.txt");
 #if defined (__WXMSW__)
-  wxString tips = wxGetCwd() + wxT("\\data\\tips.txt");
+  wxString prefix = wxGetCwd() + wxT("\\data\\");
+#elif defined (__WXMAC__)
+  wxString prefix = wxT(MACPREFIX);
+  prefix += wxT("/");
 #else
   wxString prefix = wxT(PREFIX);
-  wxString tips = prefix + wxT("/share/wxMaxima/tips.txt");
+  prefix += wxT("/");
 #endif
+  tips = prefix + tips;
   if (wxFileExists(tips)) {
-    wxTipProvider *t = wxCreateFileTipProvider(tips, tipNum);
+    MyTipProvider *t = new MyTipProvider(tips, tipNum);
     ShowTips = wxShowTip(this, t, ShowTips);
     config->Write(wxT("ShowTips"), ShowTips);
     tipNum = t->GetCurrentTip();
@@ -739,10 +778,12 @@ void wxMaxima::ShowTip(bool force)
 //
 ///////////////////////////
 
+#if WXM_PRINT
+
 void wxMaxima::PrintMenu(wxCommandEvent& event)
 {
   switch(event.GetId()) {
-    case menu_print:
+    case wxID_PRINT:
     case tb_print:
     {
       wxPrintDialogData printDialogData(*m_printData);
@@ -768,6 +809,8 @@ void wxMaxima::PrintMenu(wxCommandEvent& event)
   }
 }
 
+#endif
+
 void wxMaxima::UpdateMenus(wxUpdateUIEvent& event)
 {
   wxMenuBar* menubar = GetMenuBar();
@@ -776,10 +819,12 @@ void wxMaxima::UpdateMenus(wxUpdateUIEvent& event)
   menubar->Enable(menu_copy_as_bitmap, m_console->CanCopy());
   menubar->Enable(menu_copy_to_file, m_console->CanCopy());
   menubar->Enable(menu_delete_selection, m_console->CanDeleteSelection());
+#if WXM_PRINT
   if (m_console->GetTree()!=NULL && m_supportPrinting)
-    menubar->Enable(menu_print, true);
+    menubar->Enable(wxID_PRINT, true);
   else
-    menubar->Enable(menu_print, false);
+    menubar->Enable(wxID_PRINT, false);
+#endif
   int fontSize = 12;
   wxConfig::Get()->Read(wxT("fontSize"), &fontSize);
   if (fontSize<20)
@@ -801,10 +846,12 @@ void wxMaxima::UpdateToolBar(wxUpdateUIEvent& event)
     toolbar->EnableTool(tb_interrupt, true);
   else
     toolbar->EnableTool(tb_interrupt, false);
+#if WXM_PRINT
   if (m_console->GetTree()!=NULL && m_supportPrinting)
     toolbar->EnableTool(tb_print, true);
   else
     toolbar->EnableTool(tb_print, false);
+#endif
 }
 
 wxString wxMaxima::GetDefaultEntry()
@@ -875,8 +922,8 @@ void wxMaxima::Interrupt(wxCommandEvent& event)
   wxArrayString out;
   wxConfig::Get()->Read(wxT("maxima"), &maxima);
   wxFileName::SplitPath(maxima, &path, NULL, NULL);
-  wxString command = wxT("\"") + path;
-  command += wxString::Format(wxT("\\winkill\" -INT %ld"), m_pid);
+  wxString command = wxT("\"") + path + wxT("\\winkill.exe\"");
+  command += wxString::Format(wxT(" -INT %ld"), m_pid);
   wxExecute(command, out);
 #else
   wxProcess::Kill(m_pid, wxSIGINT);
@@ -896,6 +943,25 @@ void wxMaxima::KillMaxima()
   wxProcess::Kill(m_pid, wxSIGKILL);
 }
 
+void wxMaxima::OpenFile(wxString file, wxString cmd)
+{
+  if (file.Length()) {
+    m_lastPath = wxPathOnly(file);
+#if defined __WXMSW__
+    file.Replace(wxT("\\"), wxT("/"));
+#endif
+    if (cmd.Length())
+      SendMaxima(cmd + wxT("(\"") + file + wxT("\")$"));
+    else if (file.Right(4) == wxT(".sav")) {
+      m_console->DestroyTree();
+      SendMaxima(wxT("loadsession(\"") + file + wxT("\")$"), false, false, false);
+    }
+    else if (file.Right(4) == wxT(".dem"))
+      SendMaxima(wxT("demo(\"") + file + wxT("\")$"));
+    else
+      SendMaxima(wxT("load(\"") + file + wxT("\")$"));
+  }
+}
 void wxMaxima::FileMenu(wxCommandEvent& event)
 {
   wxString expr = GetDefaultEntry();
@@ -908,31 +974,20 @@ void wxMaxima::FileMenu(wxCommandEvent& event)
   case tb_open:
     {
       wxString file = wxFileSelector(_("Select file to open"), m_lastPath,
-									                   wxEmptyString, wxEmptyString,
+                                     wxEmptyString, wxEmptyString,
                                      _("Maxima session (*.sav)|*.sav|"
                                        "Maxima package (*.mac)|*.mac|"
                                        "Lisp package (*.lisp)|*.lisp|"
                                        "Demo file (*.dem)|*.dem|"
                                        "All|*"),
                                      wxOPEN);
-      if (file.Length()) {
-        m_lastPath = wxPathOnly(file);
-#if defined __WXMSW__
-        file.Replace(b,f);
-#endif
-        if (file.Right(4) == wxT(".sav"))
-          SendMaxima(wxT("loadfile(\"") + file + wxT("\")$"));
-        else if (file.Right(4) == wxT(".dem"))
-          SendMaxima(wxT("demo(\"") + file + wxT("\")$"));
-        else
-          SendMaxima(wxT("load(\"") + file + wxT("\")$"));
-      }
+      OpenFile(file);
     }
     break;
   case menu_open_id:
     {
       wxString file = wxFileSelector(_("Select file to open"), m_lastPath,
-									                   wxEmptyString, wxEmptyString,
+                                     wxEmptyString, wxEmptyString,
                                      _("Maxima session (*.sav)|*.sav|"
                                        "All|*"),
                                      wxOPEN);
@@ -941,7 +996,8 @@ void wxMaxima::FileMenu(wxCommandEvent& event)
 #if defined __WXMSW__
         file.Replace(b,f);
 #endif
-        SendMaxima(wxT("loadfile(\"") + file + wxT("\")$"));
+        m_console->DestroyTree();
+        SendMaxima(wxT("loadsession(\"") + file + wxT("\")$"), false, false, false);
       }
     }
     break;
@@ -962,7 +1018,7 @@ void wxMaxima::FileMenu(wxCommandEvent& event)
 #endif
         wxString cmd(wxT("save(\""));
         cmd.append(file);
-        cmd.append(wxT("\", all);"));
+        cmd.append(wxT("\", all)$"));
         SendMaxima(cmd);
       }
     }
@@ -991,38 +1047,39 @@ void wxMaxima::FileMenu(wxCommandEvent& event)
                                      _("Maxima package (*.mac)|*.mac|"
                                        "Lisp package (*.lisp)|*.lisp|All|*"),
                                      wxOPEN);
-      if (file.Length()) {
-        m_lastPath = wxPathOnly(file);
-#if defined __WXMSW__
-        file.Replace(b,f);
-#endif
-        wxString cmd(wxT("load(\""));
-        cmd.append(file);
-        cmd.append(wxT("\");"));
-        SendMaxima(cmd);
-      }
+      OpenFile(file, wxT("load"));
     }
     break;
   case menu_batch_id:
-  case tb_batch:
     {
       wxString file = wxFileSelector(_("Select package to batch"), m_lastPath,
                                      wxEmptyString, wxEmptyString,
                                      _("Maxima file (*.mac)|*.mac|"
                                        "Demo file (*.dem)|*.dem|All|*"),
                                      wxOPEN);
+      if (file.Right(4) == wxT(".dem") || file.Right(5) == wxT(".demo"))
+        OpenFile(file, wxT("demo"));
+      else
+        OpenFile(file, wxT("batch"));
+    }
+    break;
+  case menu_create_batch:
+    {
+      wxString file = wxFileSelector(_("Save to file"), m_lastPath,
+                                     wxT("wxMaxima.mac"), wxT("mac"),
+                                     _("Maxima session (*.mac)|*.mac|"
+                                       "All|*"),
+                                     wxSAVE|wxOVERWRITE_PROMPT);
       if (file.Length()) {
         m_lastPath = wxPathOnly(file);
+        if (wxFileExists(file))
+          wxRemoveFile(file);
 #if defined __WXMSW__
         file.Replace(b,f);
 #endif
-        wxString cmd;
-        if (file.Right(4) == wxT(".dem") || file.Right(5) == wxT(".demo"))
-          cmd.append(wxT("demo(\""));
-        else
-          cmd.append(wxT("batch(\""));
+        wxString cmd(wxT("stringout(\""));
         cmd.append(file);
-        cmd.append(wxT("\");"));
+        cmd.append(wxT("\", input);"));
         SendMaxima(cmd);
       }
     }
@@ -1046,7 +1103,7 @@ void wxMaxima::FileMenu(wxCommandEvent& event)
       }
     }
     break;
-  case menu_exit_id:
+  case wxID_EXIT:
     Close();
     break;
   default:
@@ -1057,10 +1114,10 @@ void wxMaxima::FileMenu(wxCommandEvent& event)
 void wxMaxima::EditMenu(wxCommandEvent& event)
 {
   switch (event.GetId()) {
-  case menu_options_id:
+  case wxID_PREFERENCES:
   case tb_pref:
     {
-      Config *configW = new Config(this,-1, _("Maxima configuration"));
+      Config *configW = new Config(this,-1, _("wxMaxima configuration"));
       configW->Centre(wxBOTH);
       if (configW->ShowModal() == wxID_OK) {
         bool match = true;
@@ -1074,7 +1131,7 @@ void wxMaxima::EditMenu(wxCommandEvent& event)
     break;
   case menu_clear_screen:
     m_console->ClearWindow();
-    ConsoleAppend(m_lastPrompt, PROMPTT);
+    ConsoleAppend(m_lastPrompt, MC_TYPE_PROMPT);
     break;
   case tb_copy:
   case menu_copy_from_console:
@@ -1164,8 +1221,20 @@ void wxMaxima::MaximaMenu(wxCommandEvent& event)
     SendMaxima(wxT("values;"));
     break;
   case menu_display:
-    cmd = wxT("if display2d#false then display2d:false else display2d:true$");
-    SendMaxima(cmd, false);
+   {
+      wxString choices[] = { wxT("xml"), wxT("ascii"),  wxT("none") };
+      wxString choice = wxGetSingleChoice(
+        _("Select math display algorithm"),
+        _("Display algorithm"),
+        3,
+        choices,
+        this
+      );
+      if (choice.Length()) {
+        cmd = wxT("set_display('") + choice + wxT(")$");
+        SendMaxima(cmd, false);
+      }
+    }
     break;
   case menu_texform:
     cmd = wxT("tex(") + expr + wxT(")$");
@@ -1215,6 +1284,7 @@ void wxMaxima::MaximaMenu(wxCommandEvent& event)
       SendMaxima(cmd);
     }
     break;
+  case menu_subst:
   case button_subst:
     {
       SubstituteWiz *wiz = new SubstituteWiz(this, -1, _("Substitute"));
@@ -1229,7 +1299,7 @@ void wxMaxima::MaximaMenu(wxCommandEvent& event)
     break;
   case button_long_input:
     {
-      TextInput *wiz = new TextInput(this, -1, _("Text input"));
+      TextInput *wiz = new TextInput(this);
       if (expr.StartsWith(wxT("<ml>"))) {
         expr = expr.SubString(4, expr.Length());
         expr.Replace(wxT("<nl>"), wxT("\n"));
@@ -1280,6 +1350,25 @@ void wxMaxima::EquationsMenu(wxCommandEvent& event)
       wiz->Destroy();
     }
     break;
+  case menu_solve_num:
+    {
+      if (expr.StartsWith(wxT("%")))
+        expr = wxT("''(") + expr + wxT(")");
+      Gen4Wiz *wiz = new Gen4Wiz(_("Solve equation:"), _("in variable:"),
+                                 _("lower bound:"), _("upper bound:"),
+                                 expr, wxT("x"), wxT("-1"), wxT("1"),
+                                 this, -1, _("Solve numerically"), true);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        cmd = wxT("find_root(") + wiz->GetValue1() + wxT(", ") +
+              wiz->GetValue2() + wxT(", ") +
+              wiz->GetValue3() + wxT(", ") +
+              wiz->GetValue4() + wxT(");");
+        SendMaxima(cmd);
+      }
+      wiz->Destroy();
+    }
+    break;
   case button_solve_ode:
   case menu_solve_ode:
     {
@@ -1694,7 +1783,7 @@ void wxMaxima::SimplifyMenu(wxCommandEvent& event)
     break;
   case menu_tellrat:
     cmd = GetTextFromUser(_("Enter an equation for rational simplification:"),
-                          _("Ratsimp"), wxEmptyString, this);
+                          _("Tellrat"), wxEmptyString, this);
     if (cmd.Length()) {
       cmd = wxT("tellrat(") + cmd + wxT(");");
       SendMaxima(cmd);
@@ -1926,20 +2015,6 @@ void wxMaxima::CalculusMenu(wxCommandEvent& event)
       wiz->Destroy();
     }
     break;
-  case menu_unsum:
-    {
-      Gen2Wiz *wiz = new Gen2Wiz(_("Unsum expression:"), _("by variable:"),
-                                 expr, wxT("n"),
-                                 this, -1, _("Unsum"));
-      wiz->Centre(wxBOTH);
-      if (wiz->ShowModal() == wxID_OK) {
-        cmd = wxT("unsum(") + wiz->GetValue1() + wxT(", ")
-          + wiz->GetValue2() + wxT(");");
-        SendMaxima(cmd);
-      }
-      wiz->Destroy();
-    }
-    break;
   case button_product:
   case menu_product:
     {
@@ -2016,7 +2091,7 @@ void wxMaxima::NumericalMenu(wxCommandEvent& event)
   wxString cmd;
   switch (event.GetId()) {
   case menu_to_float:
-    cmd = wxT("float(") + expr + wxT(");");
+    cmd = wxT("float(") + expr + wxT("), numer;");
     SendMaxima(cmd);
     break;
   case menu_to_bfloat:
@@ -2046,24 +2121,27 @@ void wxMaxima::HelpMenu(wxCommandEvent& event)
   wxString expr = GetDefaultEntry();
   wxString cmd;
   switch (event.GetId()) {
-  case menu_about_id:
+  case wxID_ABOUT:
     wxMessageBox(wxString::Format(
                  _("wxMaxima is a wxWidgets interface for the\n"
                    "computer algebra system MAXIMA.\n"
                    "\nVersion: %s."
-                   "\nReleased: %s."
                    "\nLicense: GPL.\n"
                    "\n%s\n%s"),
-                 wxT(WXMAXIMA_VERSION), wxT(WXMAXIMA_DATE),
+                 wxT(VERSION),
                  wxT("http://wxmaxima.sourceforge.net/"),
                  wxT("http://maxima.sourceforge.net/")),
                  _("About wxMaxima"), wxOK|wxICON_INFORMATION);
     break;
-  case menu_help_id:
+  case wxID_HELP:
   case tb_help:
     {
       wxString filename;
-#ifndef __WXMSW__
+#if defined __WXMSW__
+      filename = wxGetCwd() + wxT("\\data\\");
+#elif defined __WXMAC__
+      filename = wxT(MACPREFIX);
+#else
       filename = wxT(PREFIX);
       filename += wxT("/share/wxMaxima/");
       if (!wxFileExists(filename + wxT("docs.zip")))
@@ -2071,8 +2149,6 @@ void wxMaxima::HelpMenu(wxCommandEvent& event)
         filename = wxT(PREFIX);
         filename += wxT("/share/doc/wxmaxima/");
       }
-#else
-      filename = wxGetCwd() + wxT("\\data\\");
 #endif
       if (!wxFileExists(filename + wxT("intro.zip")) ||
           !wxFileExists(filename + wxT("docs.zip")))
@@ -2086,7 +2162,7 @@ void wxMaxima::HelpMenu(wxCommandEvent& event)
         if (expr == wxT("%"))
           help->DisplayContents();
         else
-          help->KeywordSearch(expr);
+          help->KeywordSearch(expr, wxHELP_SEARCH_INDEX);
       }
     }
     return;
@@ -2164,7 +2240,153 @@ void wxMaxima::OnClose(wxCloseEvent& event)
   Destroy();
 }
 
+void wxMaxima::PopupMenu(wxCommandEvent& event)
+{
+  wxString selection = m_console->GetString();
+  switch (event.GetId()) {
+  case popid_copy:
+    if (m_console->CanCopy())
+      m_console->Copy();
+    break;
+  case popid_copy_text:
+    if (m_console->CanCopy())
+      m_console->Copy(true);
+    break;
+  case popid_copy_image:
+    if (m_console->CanCopy())
+      m_console->CopyBitmap();
+    break;
+  case popid_delete:
+    if (m_console->CanDeleteSelection())
+      m_console->DeleteSelection();
+    break;
+  case popid_simplify:
+    SendMaxima(wxT("ratsimp(") + selection + wxT(");"));
+    break;
+  case popid_expand:
+    SendMaxima(wxT("expand(") + selection + wxT(");"));
+    break;
+  case popid_factor:
+    SendMaxima(wxT("factor(") + selection + wxT(");"));
+    break;
+  case popid_solve:
+    {
+      Gen2Wiz *wiz = new Gen2Wiz(_("Solve equation(s):"), _("for variable(s):"),
+                                 selection, wxT("x"), this, -1, _("Solve"), true);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        wxString cmd = wxT("solve([") + wiz->GetValue1() + wxT("], [") +
+                       wiz->GetValue2() + wxT("]);");
+        SendMaxima(cmd);
+      }
+      wiz->Destroy();
+    }
+    break;
+  case popid_solve_num:
+    {
+      Gen4Wiz *wiz = new Gen4Wiz(_("Solve equation:"), _("in variable:"),
+                                 _("lower bound:"), _("upper bound:"),
+                                 selection, wxT("x"), wxT("-1"), wxT("1"),
+                                 this, -1, _("Solve numerically"), true);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        wxString cmd = wxT("find_root(") + wiz->GetValue1() + wxT(", ") +
+                       wiz->GetValue2() + wxT(", ") +
+                      wiz->GetValue3() + wxT(", ") +
+                       wiz->GetValue4() + wxT(");");
+        SendMaxima(cmd);
+      }
+      wiz->Destroy();
+    }
+    break;
+  case popid_integrate:
+    {
+      IntegrateWiz *wiz = new IntegrateWiz(this, -1, _("Integrate"));
+      wiz->SetValue(selection);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        wxString val = wiz->GetValue();
+        SendMaxima(val);
+      }
+      wiz->Destroy();
+    }
+    break;
+  case popid_diff:
+    {
+      Gen3Wiz *wiz = new Gen3Wiz(_("Expression:"), _("in variable:"),
+                                 _("times:"), selection, wxT("x"), wxT("1"),
+                                 this, -1, _("Differentiate"));
+      wiz->setValue(selection);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        wxString val = wxT("diff(") + wiz->GetValue1() + wxT(", ") +
+          wiz->GetValue2();
+        if (wiz->GetValue3()!=wxT("1"))
+          val += wxT(", ") + wiz->GetValue3();
+        val += wxT(");");
+        SendMaxima(val);
+      }
+      wiz->Destroy();
+    }
+    break;
+  case popid_subst:
+    {
+      SubstituteWiz *wiz = new SubstituteWiz(this, -1, _("Substitute"));
+      wiz->SetValue(selection);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        wxString val = wiz->GetValue();
+        SendMaxima(val);
+      }
+      wiz->Destroy();
+    }
+    break;
+  case popid_plot2d:
+    {
+      Plot2DWiz *wiz = new Plot2DWiz(this, -1, _("Plot 2D"));
+      wiz->SetValue(selection);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        wxString val = wiz->GetValue();
+        SendMaxima(val);
+      }
+      wiz->Destroy();
+    }
+    break;
+  case popid_plot3d:
+    {
+      Plot3DWiz *wiz = new Plot3DWiz(this, -1, _("Plot 3D"));
+      wiz->SetValue(selection);
+      wiz->Centre(wxBOTH);
+      if (wiz->ShowModal() == wxID_OK) {
+        wxString val = wiz->GetValue();
+        SendMaxima(val);
+      }
+      wiz->Destroy();
+    }
+    break;
+  case popid_float:
+    SendMaxima(wxT("float(") + selection + wxT("), numer;"));
+    break;
+  }
+}
+
 BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
+  EVT_MENU(popid_copy, wxMaxima::PopupMenu)
+  EVT_MENU(popid_copy_text, wxMaxima::PopupMenu)
+  EVT_MENU(popid_copy_image, wxMaxima::PopupMenu)
+  EVT_MENU(popid_delete, wxMaxima::PopupMenu)
+  EVT_MENU(popid_simplify, wxMaxima::PopupMenu)
+  EVT_MENU(popid_factor, wxMaxima::PopupMenu)
+  EVT_MENU(popid_expand, wxMaxima::PopupMenu)
+  EVT_MENU(popid_solve, wxMaxima::PopupMenu)
+  EVT_MENU(popid_solve_num, wxMaxima::PopupMenu)
+  EVT_MENU(popid_subst, wxMaxima::PopupMenu)
+  EVT_MENU(popid_plot2d, wxMaxima::PopupMenu)
+  EVT_MENU(popid_plot3d, wxMaxima::PopupMenu)
+  EVT_MENU(popid_diff, wxMaxima::PopupMenu)
+  EVT_MENU(popid_integrate, wxMaxima::PopupMenu)
+  EVT_MENU(popid_float, wxMaxima::PopupMenu)
   EVT_TEXT_ENTER(input_line_id, wxMaxima::EnterCommand)
   EVT_BUTTON(button_integrate, wxMaxima::CalculusMenu)
   EVT_BUTTON(button_diff, wxMaxima::CalculusMenu)
@@ -2190,8 +2412,8 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_BUTTON(button_enter, wxMaxima::EnterCommand)
   EVT_MENU(menu_polarform, wxMaxima::SimplifyMenu)
   EVT_MENU(menu_restart_id, wxMaxima::MaximaMenu)
-  EVT_MENU(menu_exit_id, wxMaxima::FileMenu)
-  EVT_MENU(menu_about_id, wxMaxima::HelpMenu)
+  EVT_MENU(wxID_EXIT, wxMaxima::FileMenu)
+  EVT_MENU(wxID_ABOUT, wxMaxima::HelpMenu)
   EVT_MENU(menu_save_id, wxMaxima::FileMenu)
   EVT_MENU(menu_load_id, wxMaxima::FileMenu)
   EVT_MENU(menu_monitor_file, wxMaxima::OnMonitorFile)
@@ -2199,10 +2421,11 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_MENU(menu_select_file, wxMaxima::FileMenu)
   EVT_MENU(menu_functions, wxMaxima::MaximaMenu)
   EVT_MENU(menu_variables, wxMaxima::MaximaMenu)
-  EVT_MENU(menu_options_id, wxMaxima::EditMenu)
+  EVT_MENU(wxID_PREFERENCES, wxMaxima::EditMenu)
   EVT_MENU(menu_sconsole_id, wxMaxima::FileMenu)
   EVT_MENU(menu_export_html, wxMaxima::FileMenu)
-  EVT_MENU(menu_help_id, wxMaxima::HelpMenu)
+  EVT_MENU(menu_create_batch, wxMaxima::FileMenu)
+  EVT_MENU(wxID_HELP, wxMaxima::HelpMenu)
   EVT_MENU(menu_bug_report, wxMaxima::HelpMenu)
   EVT_MENU(menu_build_info, wxMaxima::HelpMenu)
   EVT_MENU(menu_interrupt_id, wxMaxima::Interrupt)
@@ -2234,6 +2457,7 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_MENU(menu_allroots, wxMaxima::EquationsMenu)
   EVT_MENU(menu_realroots, wxMaxima::EquationsMenu)
   EVT_MENU(menu_solve, wxMaxima::EquationsMenu)
+  EVT_MENU(menu_solve_num, wxMaxima::EquationsMenu)
   EVT_MENU(menu_solve_ode, wxMaxima::EquationsMenu)
   EVT_MENU(menu_map_mat, wxMaxima::AlgebraMenu)
   EVT_MENU(menu_enter_mat, wxMaxima::AlgebraMenu)
@@ -2246,6 +2470,7 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_MENU(menu_ivp_1, wxMaxima::EquationsMenu)
   EVT_MENU(menu_ivp_2, wxMaxima::EquationsMenu)
   EVT_MENU(menu_bvp, wxMaxima::EquationsMenu)
+  EVT_MENU(menu_bvp, wxMaxima::EquationsMenu)
   EVT_MENU(menu_fun_def, wxMaxima::MaximaMenu)
   EVT_MENU(menu_describe, wxMaxima::HelpMenu)
   EVT_MENU(menu_divide, wxMaxima::CalculusMenu)
@@ -2270,7 +2495,6 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_MENU(menu_solve_de, wxMaxima::EquationsMenu)
   EVT_MENU(menu_atvalue, wxMaxima::EquationsMenu)
   EVT_MENU(menu_sum, wxMaxima::CalculusMenu)
-  EVT_MENU(menu_unsum, wxMaxima::CalculusMenu)
   EVT_MENU(menu_product, wxMaxima::CalculusMenu)
   EVT_MENU(menu_change_var, wxMaxima::CalculusMenu)
   EVT_MENU(menu_make_list, wxMaxima::AlgebraMenu)
@@ -2299,18 +2523,22 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_MENU(menu_to_fact, wxMaxima::SimplifyMenu)
   EVT_MENU(menu_to_gamma, wxMaxima::SimplifyMenu)
   EVT_MENU(menu_goto_input, wxMaxima::MaximaMenu)
-  EVT_MENU(menu_print, wxMaxima::PrintMenu)
+#if WXM_PRINT
+  EVT_MENU(wxID_PRINT, wxMaxima::PrintMenu)
+#endif
   EVT_MENU(menu_inc_fontsize, wxMaxima::EditMenu)
   EVT_MENU(menu_dec_fontsize, wxMaxima::EditMenu)
   EVT_MENU(menu_copy_as_bitmap, wxMaxima::EditMenu)
   EVT_MENU(menu_copy_to_file, wxMaxima::EditMenu)
   EVT_MENU(menu_selection_to_input, wxMaxima::EditMenu)
+  EVT_MENU(menu_subst, wxMaxima::MaximaMenu)
   EVT_TOOL(tb_open, wxMaxima::FileMenu)
-  EVT_TOOL(tb_batch, wxMaxima::FileMenu)
   EVT_TOOL(tb_save, wxMaxima::FileMenu)
   EVT_TOOL(tb_copy, wxMaxima::EditMenu)
   EVT_TOOL(tb_delete, wxMaxima::EditMenu)
+#if WXM_PRINT
   EVT_TOOL(tb_print, wxMaxima::PrintMenu)
+#endif
   EVT_TOOL(tb_pref, wxMaxima::EditMenu)
   EVT_TOOL(tb_interrupt, wxMaxima::Interrupt)
   EVT_TOOL(tb_help, wxMaxima::HelpMenu)
@@ -2320,7 +2548,7 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_UPDATE_UI(menu_copy_lb_from_console, wxMaxima::UpdateMenus)
   EVT_UPDATE_UI(menu_inc_fontsize, wxMaxima::UpdateMenus)
   EVT_UPDATE_UI(menu_dec_fontsize, wxMaxima::UpdateMenus)
-  EVT_UPDATE_UI(menu_print, wxMaxima::UpdateMenus)
+  EVT_UPDATE_UI(wxID_PRINT, wxMaxima::UpdateMenus)
   EVT_UPDATE_UI(menu_copy_as_bitmap, wxMaxima::UpdateMenus)
   EVT_UPDATE_UI(menu_copy_to_file, wxMaxima::UpdateMenus)
   EVT_UPDATE_UI(tb_print, wxMaxima::UpdateToolBar)
