@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,15 +36,15 @@ using namespace std;
 
 #define SOCKET_SIZE 1024
 
-enum {
-  TEXTT,
-  INPUTT,
-  PROMPTT,
-  MPROMPTT,
-  ERRORT,
-  COMMENTT
+class MyApp : public wxApp
+{
+public:
+  virtual bool OnInit();
+  wxLocale m_locale;
 };
 
+DECLARE_APP(MyApp)
+
 class wxMaxima : public wxMaximaFrame
 {
  public:
@@ -53,13 +53,13 @@ class wxMaxima : public wxMaximaFrame
   ~wxMaxima();
   void ShowTip(bool force);
   void InitSession();
+  void SetOpenFile(wxString file) {m_openFile = file; }
   void SendMaxima(wxString s, bool clear=true, bool out=true,
                   bool silent=true);               // sends input to maxima
  protected:
   void EnterCommand(wxCommandEvent& event);        // enter in the command line
 
   void FileMenu(wxCommandEvent& event);            //
-  void PrintMenu(wxCommandEvent& event);           //
   void MaximaMenu(wxCommandEvent& event);          //
   void AlgebraMenu(wxCommandEvent& event);         //
   void EquationsMenu(wxCommandEvent& event);       //
@@ -76,17 +76,21 @@ class wxMaxima : public wxMaximaFrame
   void UpdateMenus(wxUpdateUIEvent& event);        //
   void UpdateToolBar(wxUpdateUIEvent& event);      //
   void OnProcessEvent(wxProcessEvent& event);      //
+  void PopupMenu(wxCommandEvent& event);           //
 
   void ServerEvent(wxSocketEvent& event);          // server event: maxima connection
   void ClientEvent(wxSocketEvent& event);          // client event: maxima input/output
-  
-  void ConsoleAppend(wxString s, int type = TEXTT);// append maxima output to console
+
+  void ConsoleAppend(wxString s, int type);// append maxima output to console
   void DoConsoleAppend(wxString s, int type,       //
           bool newLine, bool bigSkip = true);      //
   void DoRawConsoleAppend(wxString s, int type,    //
           bool newLine = true);                    //
-  
+
+#if WXM_PRINT
   void CheckForPrintingSupport();
+  void PrintMenu(wxCommandEvent& event);
+#endif
   wxString GetDefaultEntry();
   bool StartServer();                              // starts the server
   bool StartMaxima();                              // starts maxima (uses getCommand)
@@ -101,12 +105,15 @@ class wxMaxima : public wxMaximaFrame
   void ReadPrompt();                 // reads prompts
   void ReadMath();                   // reads output other than prompts
   void ReadLispError();              // lisp errors (no prompt prefix/suffix)
+  void OpenFile(wxString file,
+                wxString command=wxEmptyString);      // Open a file
 #ifndef __WXMSW__
   void ReadProcessOutput();          // reads output of maxima command
 #endif
   void SetupVariables();             // sets some maxima variables
   void KillMaxima();                 // kills the maxima process
   void FirstOutput(wxString s);
+  wxString RemoveTabs(wxString s);
   wxSocketBase *m_client;
   wxSocketServer *m_server;
   bool m_isConnected;
@@ -130,8 +137,11 @@ class wxMaxima : public wxMaximaFrame
   wxString m_lastPath;
   MathParser m_MParser;
   wxPrintData* m_printData;
+#if WXM_PRINT
   bool m_supportPrinting;
+#endif
   bool m_closing;
+  wxString m_openFile;
   DECLARE_EVENT_TABLE()
 };
 
