@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2005 Andrej Vodopivec <andrejv@users.sourceforge.net>
+ *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 
 
 #include "wxMaximaFrame.h"
-#include "Version.h"
 
 #include <wx/artprov.h>
 #include <wx/config.h>
@@ -38,7 +37,7 @@ wxMaximaFrame::wxMaximaFrame(wxWindow* parent, int id, const wxString& title,
   wxFrame(parent, id, title, pos, size, wxDEFAULT_FRAME_STYLE)
 {
   panel = new wxPanel(this, -1);
-  
+
   // input line
   label_1 = new wxStaticText(panel, -1, _("INPUT:"));
   m_inputLine = new CommandLine(panel, input_line_id, wxEmptyString,
@@ -49,39 +48,57 @@ wxMaximaFrame::wxMaximaFrame(wxWindow* parent, int id, const wxString& title,
                                 wxBitmap(ok_xpm));
   button_1 = new wxBitmapButton(panel, button_long_input,
                                 wxBitmap(multiline_xpm));
-  
+
   // buttons
-  button_2 = new wxButton(panel, button_ratsimp, _("Simplify"));
-  button_3 = new wxButton(panel, button_radcan, _("Simplify (r)"));
-  button_4 = new wxButton(panel, button_factor, _("Factor"));
-  button_5 = new wxButton(panel, button_expand, _("Expand"));
-  button_6 = new wxButton(panel, button_trigsimp, _("Simplify (tr)"));
-  button_7 = new wxButton(panel, button_trigexpand, _("Expand (tr)"));
-  button_8 = new wxButton(panel, button_trigreduce, _("Reduce (tr)"));
-  button_9 = new wxButton(panel, button_rectform, _("Rectform"));
-  button_10 = new wxButton(panel, button_sum, _("Sum..."));
-  button_11 = new wxButton(panel, button_product, _("Product..."));
-  button_12 = new wxButton(panel, button_solve, _("Solve..."));
-  button_13 = new wxButton(panel, button_solve_ode, _("Solve ODE..."));
-  button_14 = new wxButton(panel, button_diff, _("Diff..."));
-  button_15 = new wxButton(panel, button_integrate, _("Integrate..."));
-  button_16 = new wxButton(panel, button_limit, _("Limit..."));
-  button_17 = new wxButton(panel, button_taylor, _("Series..."));
-  button_18 = new wxButton(panel, button_subst, _("Substitute..."));
-  button_19 = new wxButton(panel, button_map, _("Map..."));
-  button_20 = new wxButton(panel, button_plot2, _("Plot 2D..."));
-  button_21 = new wxButton(panel, button_plot3, _("Plot 3D..."));
-  
+  int panelSize = 1;
+  wxConfig::Get()->Read(wxT("panelSize"), &panelSize);
+  if (panelSize == 2) {
+    button_2 = new wxButton(panel, button_ratsimp, _("Simplify"));
+    button_3 = new wxButton(panel, button_radcan, _("Simplify (r)"));
+    button_4 = new wxButton(panel, button_factor, _("Factor"));
+    button_5 = new wxButton(panel, button_expand, _("Expand"));
+    button_6 = new wxButton(panel, button_trigsimp, _("Simplify (tr)"));
+    button_7 = new wxButton(panel, button_trigexpand, _("Expand (tr)"));
+    button_8 = new wxButton(panel, button_trigreduce, _("Reduce (tr)"));
+    button_9 = new wxButton(panel, button_rectform, _("Rectform"));
+    button_10 = new wxButton(panel, button_sum, _("Sum..."));
+    button_11 = new wxButton(panel, button_product, _("Product..."));
+    button_12 = new wxButton(panel, button_solve, _("Solve..."));
+    button_13 = new wxButton(panel, button_solve_ode, _("Solve ODE..."));
+    button_14 = new wxButton(panel, button_diff, _("Diff..."));
+    button_15 = new wxButton(panel, button_integrate, _("Integrate..."));
+    button_16 = new wxButton(panel, button_limit, _("Limit..."));
+    button_17 = new wxButton(panel, button_taylor, _("Series..."));
+    button_18 = new wxButton(panel, button_subst, _("Substitute..."));
+    button_19 = new wxButton(panel, button_map, _("Map..."));
+    button_20 = new wxButton(panel, button_plot2, _("Plot 2D..."));
+    button_21 = new wxButton(panel, button_plot3, _("Plot 3D..."));
+  }
+  else if (panelSize == 1) {
+    button_2 = new wxButton(panel, button_ratsimp, _("Simplify"));
+    button_3 = new wxButton(panel, button_radcan, _("Simplify (r)"));
+    button_4 = new wxButton(panel, button_factor, _("Factor"));
+    button_5 = new wxButton(panel, button_expand, _("Expand"));
+    button_12 = new wxButton(panel, button_solve, _("Solve..."));
+    button_20 = new wxButton(panel, button_plot2, _("Plot 2D..."));
+    button_6 = new wxButton(panel, button_trigsimp, _("Simplify (tr)"));
+    button_7 = new wxButton(panel, button_trigexpand, _("Expand (tr)"));
+    button_8 = new wxButton(panel, button_trigreduce, _("Reduce (tr)"));
+    button_9 = new wxButton(panel, button_rectform, _("Rectform"));
+    button_13 = new wxButton(panel, button_solve_ode, _("Solve ODE..."));
+    button_21 = new wxButton(panel, button_plot3, _("Plot 3D..."));
+  }
+
   // console
   m_console = new MathCtrl(panel, -1, wxDefaultPosition, wxDefaultSize);
 
   SetupMenu();
   SetupToolBar();
-  
+
   frame_1_statusbar = CreateStatusBar(2);
   int widths[] = {-1, 300};
   SetStatusWidths(2, widths);
-  
+
   set_properties();
   do_layout();
 }
@@ -89,18 +106,20 @@ wxMaximaFrame::wxMaximaFrame(wxWindow* parent, int id, const wxString& title,
 void wxMaximaFrame::set_properties()
 {
   SetIcon(wxICON(maximaicon));
-  SetTitle(wxString::Format(_("wxMaxima %s"), wxT(WXMAXIMA_VERSION)));
+  SetTitle(wxString::Format(_("wxMaxima %s"), wxT(VERSION)));
   bool fixed = true;
   wxConfig::Get()->Read(wxT("fixedFontTC"), &fixed);
   if (fixed) {
   // Set font for input line
-#if defined(__WXGTK12__) && !defined(__WXGTK20__)
+#if defined (__WXGTK12__) && !defined (__WXGTK20__)
+    m_inputLine->SetFont(wxFont(12, wxMODERN, wxNORMAL, wxNORMAL, 0, wxEmptyString));
+#elif defined (__WXMAC__)
     m_inputLine->SetFont(wxFont(12, wxMODERN, wxNORMAL, wxNORMAL, 0, wxEmptyString));
 #else
     m_inputLine->SetFont(wxFont(10, wxMODERN, wxNORMAL, wxNORMAL, 0, wxEmptyString));
 #endif
   }
-  
+
   m_console->SetBackgroundColour(wxColour(wxT("WHITE")));
 #if wxCHECK_VERSION(2, 5, 0)
   m_console->SetMinSize(wxSize(100, 100));
@@ -113,33 +132,63 @@ void wxMaximaFrame::set_properties()
 
 void wxMaximaFrame::do_layout()
 {
-  wxFlexGridSizer* grid_sizer_1 = new wxFlexGridSizer(3, 1, 0, 0);
+  int panelSize = 1;
+  wxConfig::Get()->Read(wxT("panelSize"), &panelSize);
+
+  wxFlexGridSizer* grid_sizer_1;
+  if (panelSize > 1)
+    grid_sizer_1 = new wxFlexGridSizer(3, 1, 0, 0);
+  else
+    grid_sizer_1 = new wxFlexGridSizer(2, 1, 0, 0);
+
   wxBoxSizer *sizer_1 = new wxBoxSizer(wxHORIZONTAL);
-  wxGridSizer* grid_sizer_2 = new wxGridSizer(2, 10, 0, 0);
+
+  wxGridSizer* grid_sizer_2;
+  if (panelSize == 2)
+    grid_sizer_2 = new wxGridSizer(2, 10, 0, 0);
+  else
+    grid_sizer_2 = new wxGridSizer(2, 6, 0, 0);
+
   wxFlexGridSizer* sizer_3 = new wxFlexGridSizer(1, 4, 0, 0);
 
   // buttons
-  grid_sizer_2->Add(button_2, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_3, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_4, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_5, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_6, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_7, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_8, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_9, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_10, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_11, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_12, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_13, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_14, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_15, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_16, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_17, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_18, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_19, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_20, 0, wxALL|wxEXPAND, 0);
-  grid_sizer_2->Add(button_21, 0, wxALL|wxEXPAND, 0);
-   
+  if (panelSize == 2) {
+    grid_sizer_2->Add(button_2, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_3, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_4, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_5, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_6, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_7, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_8, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_9, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_10, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_11, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_12, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_13, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_14, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_15, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_16, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_17, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_18, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_19, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_20, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_21, 0, wxALL|wxEXPAND, 0);
+  }
+  else {
+    grid_sizer_2->Add(button_2, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_3, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_4, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_5, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_12, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_20, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_6, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_7, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_8, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_9, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_13, 0, wxALL|wxEXPAND, 0);
+    grid_sizer_2->Add(button_21, 0, wxALL|wxEXPAND, 0);
+  }
+
   // input line
   sizer_3->Add(label_1, 0, wxALL|wxALIGN_CENTER_HORIZONTAL|
                wxALIGN_CENTER_VERTICAL, 2);
@@ -147,12 +196,14 @@ void wxMaximaFrame::do_layout()
   sizer_3->Add(button_0, 0, wxALL|wxALIGN_CENTER_VERTICAL, 2);
   sizer_3->Add(button_1, 0, wxALL|wxALIGN_CENTER_VERTICAL, 2);
   sizer_3->AddGrowableCol(1);
-  
+
   // all
   grid_sizer_1->Add(m_console, 1, wxALL|wxEXPAND, 0);
   grid_sizer_1->Add(sizer_3, 1, wxALL|wxEXPAND, 0);
-  grid_sizer_1->Add(grid_sizer_2, 1, wxALL, 2);
-  
+
+  if (panelSize > 0)
+    grid_sizer_1->Add(grid_sizer_2, 1, wxALL, 2);
+
   panel->SetAutoLayout(true);
   panel->SetSizer(grid_sizer_1);
   grid_sizer_1->Fit(panel);
@@ -170,7 +221,7 @@ void wxMaximaFrame::SetupMenu()
 {
   frame_1_menubar = new wxMenuBar();
   wxMenuItem *tmp_menu_item;
-  
+
 #if defined __WXGTK20__
  #define APPEND_MENU_ITEM(menu, id, label, help, stock)                         \
   tmp_menu_item = new wxMenuItem((menu), (id), (label), (help), wxITEM_NORMAL); \
@@ -180,7 +231,7 @@ void wxMaximaFrame::SetupMenu()
  #define APPEND_MENU_ITEM(menu, id, label, help, stock) \
   (menu)->Append((id), (label), (help), wxITEM_NORMAL);
 #endif
-  
+
   // File menu
   wxMenu* wxglade_tmp_menu_1 = new wxMenu();
   APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_open_id, _("&Open session\tCtrl-O"),
@@ -191,6 +242,8 @@ void wxMaximaFrame::SetupMenu()
                    _("Load a maxima package file"), wxITEM_NORMAL);
   APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_batch_id, _("&Batch file\tCtrl-B"),
                    _("Batch maxima file"), wxT("gtk-execute"));
+  wxglade_tmp_menu_1->Append(menu_create_batch, _("&Create batch file"),
+                   _("Create a batch file from current session"));
   APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_export_html, _("&Export to HTML"),
                    _("Export console output to HTML file"), wxT("stock_export"));
   wxglade_tmp_menu_1->AppendSeparator();
@@ -200,11 +253,13 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_1->Append(menu_monitor_file, _("&Monitor file"),
                              _("Autoload a file when it is updated"),
                              wxITEM_NORMAL);
+#if WXM_PRINT
   wxglade_tmp_menu_1->AppendSeparator();
-  APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_print, _("&Print\tCtrl-P"),
+  APPEND_MENU_ITEM(wxglade_tmp_menu_1, wxID_PRINT, _("&Print\tCtrl-P"),
                    _("Print document"), wxT("gtk-print"));
+#endif
   wxglade_tmp_menu_1->AppendSeparator();
-  APPEND_MENU_ITEM(wxglade_tmp_menu_1, menu_exit_id, _("E&xit\tCtrl-Q"),
+  APPEND_MENU_ITEM(wxglade_tmp_menu_1, wxID_EXIT, _("E&xit\tCtrl-Q"),
                    _("Exit wxMaxima"), wxT("gtk-quit"));
   frame_1_menubar->Append(wxglade_tmp_menu_1, _("&File"));
 
@@ -240,7 +295,7 @@ void wxMaximaFrame::SetupMenu()
                              _("Set focus to the input line"),
                              wxITEM_NORMAL);
   wxglade_tmp_menu_2->AppendSeparator();
-  APPEND_MENU_ITEM(wxglade_tmp_menu_2, menu_options_id, _("C&onfigure"),
+  APPEND_MENU_ITEM(wxglade_tmp_menu_2, wxID_PREFERENCES, _("C&onfigure"),
                    _("Configure wxMaxima"), wxT("gtk-preferences"));
   frame_1_menubar->Append(wxglade_tmp_menu_2, _("&Edit"));
 
@@ -251,8 +306,8 @@ void wxMaximaFrame::SetupMenu()
                    _("Interrupt current computation"), wxT("gtk-stop"));
   APPEND_MENU_ITEM(wxglade_tmp_menu_2, menu_restart_id,
                    _("&Restart maxima"), _("Restart maxima"), wxT("gtk-refresh"));
-  wxglade_tmp_menu_2->Append(menu_soft_restart, _("&Soft restart"),
-                             _("Restart maxima (softly)"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->Append(menu_soft_restart, _("&Clear memory"),
+                             _("Delete all values from memory"), wxITEM_NORMAL);
   APPEND_MENU_ITEM(wxglade_tmp_menu_2, menu_add_path, _("Add to &path"),
                    _("Add a directory to search path"),wxT("gtk-add"));
   wxglade_tmp_menu_2->AppendSeparator();
@@ -271,8 +326,8 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_2->Append(menu_time, _("Toggle &time display"),
                              _("Display time used for execution"),
                              wxITEM_NORMAL);
-  wxglade_tmp_menu_2->Append(menu_display, _("Toggle &2d display"),
-                             _("Toggle the 2d display of maxima output"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->Append(menu_display, _("Change &2d display"),
+                             _("Change the 2d display algorithm used to display math output."), wxITEM_NORMAL);
   wxglade_tmp_menu_2->Append(menu_texform, _("Display Te&X form"),
                              _("Display expression in TeX form"), wxITEM_NORMAL);
   frame_1_menubar->Append(wxglade_tmp_menu_2, _("&Maxima"));
@@ -281,6 +336,8 @@ void wxMaximaFrame::SetupMenu()
   wxMenu* wxglade_tmp_menu_3 = new wxMenu();
   wxglade_tmp_menu_3->Append(menu_solve, _("&Solve ..."),
                              _("Solve equation(s)"), wxITEM_NORMAL);
+  wxglade_tmp_menu_3->Append(menu_solve_num, _("Solve &numerically ..."),
+                             _("Find a root of an equation on an interval"), wxITEM_NORMAL);
   wxglade_tmp_menu_3->Append(menu_allroots, _("Roots of &polynomial"),
                              _("Find all roots of a polynomial"),
                              wxITEM_NORMAL);
@@ -379,9 +436,6 @@ void wxMaximaFrame::SetupMenu()
                              wxITEM_NORMAL);
   wxglade_tmp_menu_6->Append(menu_sum, _("Calculate su&m ..."),
                              _("Calculate sums"), wxITEM_NORMAL);
-  wxglade_tmp_menu_6->Append(menu_unsum, _("U&nsum expression ..."),
-                             _("What has to be summed to get this result"),
-                             wxITEM_NORMAL);
   wxglade_tmp_menu_6->Append(menu_product, _("Calculate &product ..."),
                              _("Calculate products"), wxITEM_NORMAL);
   wxglade_tmp_menu_6->Append(menu_laplace, _("Laplace &transform ..."),
@@ -457,8 +511,8 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_5_sub2->Append(menu_trigexpand, _("&Expand trigonometric"),
                              _("Expand trigonometric expression"),
                              wxITEM_NORMAL);
-  wxglade_tmp_menu_5_sub2->Append(menu_trigrat, _("R&ationalize trigonometric"),
-                             _("Rationalize trigonometrix expression"),
+  wxglade_tmp_menu_5_sub2->Append(menu_trigrat, _("&Canonical form"),
+                             _("Convert trigonometric expression to canonical quasilinear form"),
                              wxITEM_NORMAL);
   wxglade_tmp_menu_5->Append(wxNewId(), _("&Trigonometric simplification"),
                              wxglade_tmp_menu_5_sub2,
@@ -485,12 +539,15 @@ void wxMaximaFrame::SetupMenu()
                              wxglade_tmp_menu_5_sub3,
                              _("Functions for complex simplification"));
   wxglade_tmp_menu_5->AppendSeparator();
+  wxglade_tmp_menu_5->Append(menu_subst, _("Substitute ..."),
+                             _("Make substitution in expression"),
+                             wxITEM_NORMAL);
   wxglade_tmp_menu_5->Append(menu_nouns, _("Evaluate &noun forms"),
                              _("Evaluate all noun forms in expression"),
                              wxITEM_NORMAL);
-  wxglade_tmp_menu_5->Append(menu_talg, _("Toggle &algebraic"),
-                             _("Toggle algebraic computation"), wxITEM_NORMAL);
-  wxglade_tmp_menu_5->Append(menu_tellrat, _("Add algebraic e&quality"),
+  wxglade_tmp_menu_5->Append(menu_talg, _("Toggle &algebraic flag"),
+                             _("Toggle algebraic flag"), wxITEM_NORMAL);
+  wxglade_tmp_menu_5->Append(menu_tellrat, _("Add algebraic e&quality ..."),
                              _("Add equality to the rational simplifier"),
                              wxITEM_NORMAL);
   wxglade_tmp_menu_5->Append(menu_modulus, _("&Modulus computation ..."),
@@ -524,7 +581,7 @@ void wxMaximaFrame::SetupMenu()
 
   // Help menu
   wxMenu* wxglade_tmp_menu_7 = new wxMenu();
-  APPEND_MENU_ITEM(wxglade_tmp_menu_7, menu_help_id, _("Maxima &help\tF1"),
+  APPEND_MENU_ITEM(wxglade_tmp_menu_7, wxID_HELP, _("Maxima &help\tF1"),
                    _("Show maxima help"), wxT("gtk-help"));
   APPEND_MENU_ITEM(wxglade_tmp_menu_7, menu_describe, _("&Describe\tCtrl-H"),
                    _("Show the description of a command"),wxT("gtk-help"));
@@ -542,7 +599,7 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_7->Append(menu_bug_report, _("&Bug report"),
                              _("Report bug"), wxITEM_NORMAL);
   wxglade_tmp_menu_7->AppendSeparator();
-  APPEND_MENU_ITEM(wxglade_tmp_menu_7, menu_about_id, _("About"),
+  APPEND_MENU_ITEM(wxglade_tmp_menu_7, wxID_ABOUT, _("About"),
                    _("About wxMaxima"), wxT("stock_about"));
   frame_1_menubar->Append(wxglade_tmp_menu_7, _("&Help"));
 
@@ -560,14 +617,16 @@ void wxMaximaFrame::SetupMenu()
 void wxMaximaFrame::SetupToolBar()
 {
   wxToolBar* frame_1_toolbar = CreateToolBar();
-  
+
   frame_1_toolbar->AddTool(tb_open, _("Open"),
                            wxBitmap(open_xpm), _("Open session"));
   frame_1_toolbar->AddTool(tb_save, _("Save"),
                            wxBitmap(save_xpm), _("Save session"));
   frame_1_toolbar->AddSeparator();
+#if WXM_PRINT
   frame_1_toolbar->AddTool(tb_print, _("Print"),
                            wxBitmap(print_xpm), _("Print document"));
+#endif
   frame_1_toolbar->AddTool(tb_pref, _("Options"),
                            wxBitmap(pref_xpm), _("Configure wxMaxima"));
   frame_1_toolbar->AddSeparator();
@@ -582,7 +641,7 @@ void wxMaximaFrame::SetupToolBar()
   frame_1_toolbar->AddSeparator();
   frame_1_toolbar->AddTool(tb_help, _("Help"),
                            wxBitmap(help_xpm), _("Show maxima help"));
-  
+
   frame_1_toolbar->Realize();
   SetToolBar(frame_1_toolbar);
 }
@@ -592,7 +651,7 @@ void wxMaximaFrame::SetupToolBar()
 void wxMaximaFrame::SetupToolBar()
 {
   wxToolBar* frame_1_toolbar = CreateToolBar();
-  
+
   frame_1_toolbar->AddTool(tb_open, _("Open"),
                            wxArtProvider::GetBitmap(wxT("gtk-open"),
                                                     wxART_TOOLBAR),
@@ -602,10 +661,12 @@ void wxMaximaFrame::SetupToolBar()
                                                     wxART_TOOLBAR),
                            _("Save session"));
   frame_1_toolbar->AddSeparator();
+#if WXM_PRINT
   frame_1_toolbar->AddTool(tb_print, _("Print"),
                            wxArtProvider::GetBitmap(wxT("gtk-print"),
                                                     wxART_TOOLBAR),
                            _("Print document"));
+#endif
   frame_1_toolbar->AddTool(tb_pref, _("Options"),
                            wxArtProvider::GetBitmap(wxT("gtk-preferences"),
                                                     wxART_TOOLBAR),
@@ -629,7 +690,7 @@ void wxMaximaFrame::SetupToolBar()
                            wxArtProvider::GetBitmap(wxT("gtk-help"),
                                                     wxART_TOOLBAR),
                            _("Show maxima help"));
-  
+
   frame_1_toolbar->Realize();
   SetToolBar(frame_1_toolbar);
 }
